>From 067dfc7640a48ab3ba18eaa858eda75d102598b6 Mon Sep 17 00:00:00 2001
From: Alvaro Herrera <alvherre@alvh.no-ip.org>
Date: Mon, 8 Sep 2014 17:55:07 -0300
Subject: [PATCH 30/30] deparse: Support ALTER TABLE ALL IN TABLESPACE

This version emits one ALTER TABLE command for each table affected by
the ALL IN TABLESPACE variant.  We might revisit this later.
---
 src/backend/commands/tablecmds.c   | 2 ++
 src/backend/tcop/deparse_utility.c | 1 +
 src/backend/tcop/utility.c         | 1 +
 3 files changed, 4 insertions(+)

diff --git a/src/backend/commands/tablecmds.c b/src/backend/commands/tablecmds.c
index 056f0c6..9624a59 100644
--- a/src/backend/commands/tablecmds.c
+++ b/src/backend/commands/tablecmds.c
@@ -9572,7 +9572,9 @@ AlterTableMoveAll(AlterTableMoveAllStmt *stmt)
 
 		cmds = lappend(cmds, cmd);
 
+		EventTriggerComplexCmdStart((Node *) stmt, OBJECT_TABLE);
 		AlterTableInternal(lfirst_oid(l), cmds, false);
+		EventTriggerComplexCmdEnd();
 	}
 
 	return new_tablespaceoid;
diff --git a/src/backend/tcop/deparse_utility.c b/src/backend/tcop/deparse_utility.c
index 9c02626..80d0bbf 100644
--- a/src/backend/tcop/deparse_utility.c
+++ b/src/backend/tcop/deparse_utility.c
@@ -4627,6 +4627,7 @@ deparse_parsenode_cmd(StashedCommand *cmd)
 			break;
 
 		case T_AlterTableStmt:
+		case T_AlterTableMoveAllStmt:
 			command = deparse_AlterTableStmt(cmd);
 			break;
 
diff --git a/src/backend/tcop/utility.c b/src/backend/tcop/utility.c
index 388157f..43a42ac 100644
--- a/src/backend/tcop/utility.c
+++ b/src/backend/tcop/utility.c
@@ -1370,6 +1370,7 @@ ProcessUtilitySlow(Node *parsetree,
 				break;
 
 			case T_AlterTableMoveAllStmt:
+				/* commands are stashed in AlterTableMoveAll */
 				AlterTableMoveAll((AlterTableMoveAllStmt *) parsetree);
 				break;
 
-- 
1.9.1

